==> claromentis-framework-9.6.6-26891208.zip: console/src/Output/MultiplexedOutput.php <==
<?php
namespace Claromentis\Console\Output;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_db6f0ba0791e9a6354076" . "59a9fe04e40" => base64_decode("aXNfb2JqZWN" . "0"), "_e41dd208b3f8688e037c1f57903a2a" . "f3" => base64_decode("T3V0cH" . "V0IGlu" . "dGVyZm" . "FjZSAn"), "_b2c18fea2fd27be5faced70" . "fc93730a8" => base64_decode("JyBkb2V" . "zIG5vdC" . "BpbXBsZ" . "W1lbnQg"), "_fc9d7314a9d9958d8fa0a403ba8ff1" . "97" => base64_decode("Z2V0X" . "2NsYX" . "Nz"), "_2b879ee7476ab710ec" . "475ba39e3fe902" => base64_decode("aXNfYQ" . "=="));
use Symfony\Component\Console\Formatter\OutputFormatter;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Output\OutputInterface;




class MultiplexedOutput implements OutputInterface
{
    
    
    
    
    protected $verbosity = self::VERBOSITY_NORMAL;
    
    
    
    
    protected $formatter = null;
    
    
    
    
    protected $interfaces = [];
    
    
    
    
    
    
    
    
    
    public function __construct(array $_3afbfd6216bfbb1e35b97511f18c8397, $_e84eb3b6c91429c62da5eddaef93bb19 = self::VERBOSITY_NORMAL, $_4de82f87bac18df795ec4161918650aa = null, OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3 = null)
    {
        $this->verbosity = $_e84eb3b6c91429c62da5eddaef93bb19;
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        if ($this->formatter === null) {
            $this->formatter = new OutputFormatter($_4de82f87bac18df795ec4161918650aa);
        }
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            if (!$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_db6f0ba0791" . "e9a635407659" . "a9fe04e40"]($_5b08afc6598666e83143bd42ce733d9c)) {
                continue;
            }
            if (!$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_2b879ee7476a" . "b710ec475ba39" . "e3fe902"]($_5b08afc6598666e83143bd42ce733d9c, OutputInterface::class)) {
                $_6b33cbff9a72786d9d5e3d7fc9322a40 = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_fc9d7314a9d9958d8f" . "a0a403ba8ff197"]($_5b08afc6598666e83143bd42ce733d9c);
                throw new \InvalidArgumentException($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_e41dd208b3f8688e0" . "37c1f57903a2af3"] . $_6b33cbff9a72786d9d5e3d7fc9322a40 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_b2c18fea2fd27b" . "e5faced70fc9373" . "0a8"] . OutputInterface::class);
            }
            $this->interfaces[] = $_5b08afc6598666e83143bd42ce733d9c;
        }
    }
    
    
    
    
    
    
    public function getInterfaces()
    {
        return $this->interfaces;
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        $this->verbosity = $_8571ac32155d45081f21fab1bc366aff;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->verbosity;
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_QUIET;
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERBOSE;
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERY_VERBOSE;
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_DEBUG;
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        $this->formatter->setDecorated($_4de82f87bac18df795ec4161918650aa);
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->getFormatter()->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->formatter->isDecorated();
    }
    
    
    
    
    
    
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->formatter;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: console/src/Output/MultiplexedOutput.php <==
<?php
namespace Claromentis\Console\Output;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_b2c18fea2" . "fd27be5fac" . "ed70fc9373" . "0a8" => base64_decode("JyBkb2VzIG5vdCBpbXBsZW1" . "lbnQg"), "_db6f0ba0791" . "e9a635407659" . "a9fe04e40" => base64_decode("aXNfb2JqZWN" . "0"), "_e41dd208b3f8688" . "e037c1f57903a2af" . "3" => base64_decode("T3V0cHV0IGludGVyZmFj" . "ZSAn"), "_2b879ee7476ab710ec475ba3" . "9e3fe902" => base64_decode("aXNfYQ=" . "="), "_fc9d7314a9d9958d8fa0" . "a403ba8ff197" => base64_decode("Z2V" . "0X2" . "NsY" . "XNz"));
use Symfony\Component\Console\Formatter\OutputFormatter;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Output\OutputInterface;




class MultiplexedOutput implements OutputInterface
{
    
    
    
    
    protected $verbosity = self::VERBOSITY_NORMAL;
    
    
    
    
    protected $formatter = null;
    
    
    
    
    protected $interfaces = [];
    
    
    
    
    
    
    
    
    
    public function __construct(array $_3afbfd6216bfbb1e35b97511f18c8397, $_e84eb3b6c91429c62da5eddaef93bb19 = self::VERBOSITY_NORMAL, $_4de82f87bac18df795ec4161918650aa = null, OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3 = null)
    {
        $this->verbosity = $_e84eb3b6c91429c62da5eddaef93bb19;
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        if ($this->formatter === null) {
            $this->formatter = new OutputFormatter($_4de82f87bac18df795ec4161918650aa);
        }
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            if (!$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_db6f0ba0791e9a635407659a9f" . "e04e40"]($_5b08afc6598666e83143bd42ce733d9c)) {
                continue;
            }
            if (!$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_2b879ee747" . "6ab710ec475" . "ba39e3fe902"]($_5b08afc6598666e83143bd42ce733d9c, OutputInterface::class)) {
                $_6b33cbff9a72786d9d5e3d7fc9322a40 = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_fc9d7314a9d9958d8f" . "a0a403ba8ff197"]($_5b08afc6598666e83143bd42ce733d9c);
                throw new \InvalidArgumentException($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_e41dd208b3" . "f8688e037c1" . "f57903a2af3"] . $_6b33cbff9a72786d9d5e3d7fc9322a40 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_b2c18fea2fd27be5fac" . "ed70fc93730a8"] . OutputInterface::class);
            }
            $this->interfaces[] = $_5b08afc6598666e83143bd42ce733d9c;
        }
    }
    
    
    
    
    
    
    public function getInterfaces()
    {
        return $this->interfaces;
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        $this->verbosity = $_8571ac32155d45081f21fab1bc366aff;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->verbosity;
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_QUIET;
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERBOSE;
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERY_VERBOSE;
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_DEBUG;
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        $this->formatter->setDecorated($_4de82f87bac18df795ec4161918650aa);
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->getFormatter()->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->formatter->isDecorated();
    }
    
    
    
    
    
    
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->formatter;
    }
}
